@@ -28,13 +28,17 @@
 #'    iedrver). If new versions are available they will be downloaded.
 #' @param verbose If TRUE, include status messages (if any)
 #' @param retcommand If TRUE return only the command that would be passed
-#'     to \code{\link{spawn_process}}
+#'     to \code{\link[processx]{process}}
 #' @param ... pass additional options to the driver
-#' @return Returns a list with named elements process, output, error
-#'     and stop. process is the output from calling \code{\link{spawn_process}}
-#'     output, error and stop are functions calling
-#'     \code{\link{process_read}}, \code{\link{process_read}} with "stderr"
-#'     pipe and \code{\link{process_kill}}  respectively  on process.
+#'
+#' @return Returns a list with named elements \code{process}, \code{output},
+#'     \code{error}, \code{stop}, and \code{log}.
+#'     \code{process} is the object from calling \code{\link[processx]{process}}.
+#'     \code{output} and \code{error} are the functions reading the latest
+#'     messages from "stdout" and "stderr" since the last call whereas \code{log}
+#'     is the function that reads all messages.
+#'     Lastly, \code{stop} call the \code{kill} method in
+#'     \code{\link[processx]{process}} to the kill the \code{process}.
 #' @export
 #'
 #' @examples
@@ -83,16 +87,16 @@ selenium <- function(port = 4567L,
   pfile <- pipe_files()
   seleniumdrv <- spawn_tofile(javapath, args = c(jvmargs, selargs),
                               pfile[["out"]], pfile[["err"]])
-  if(!is.na(subprocess::process_return_code(seleniumdrv))){
-    stop("Selenium server couldn't be started",
-         subprocess::process_read(seleniumdrv, "stderr"))
+  if(isFALSE(seleniumdrv$is_alive())){
+    err <- paste0(readLines(pfile[["err"]]), collapse = "\n")
+    stop("Selenium server  couldn't be started\n", err)
   }
-  startlog <- generic_start_log(seleniumdrv, poll = 10000L,
+  startlog <- generic_start_log(seleniumdrv, # poll = 10000L,
                                 outfile = pfile[["out"]],
                                 errfile = pfile[["err"]])
   if(length(startlog[["stderr"]]) >0){
     if(any(grepl("Address already in use", startlog[["stderr"]]))){
-      subprocess::process_kill(seleniumdrv)
+      seleniumdrv$kill()
       stop("Selenium server signals port = ", port, " is already in use.")
     }
   }else{
@@ -112,7 +116,7 @@ selenium <- function(port = 4567L,
       infun_read(seleniumdrv, log, "stderr", timeout = timeout,
                  outfile = pfile[["out"]], errfile = pfile[["err"]])
     },
-    stop = function(){subprocess::process_kill(seleniumdrv)},
+    stop = function(){seleniumdrv$kill()},
     log = function(){
       infun_read(seleniumdrv, log,
                  outfile = pfile[["out"]], errfile = pfile[["err"]])
